--- title: "wallaroo.connection" type: docs linkTitle: "wallaroo.connection" ---
class Connection(wallaroo.object.Object):

Connection to an external data source or destination.

Connection( client: wallaroo.client.Client, data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

@staticmethod
def list_connections( client: wallaroo.client.Client, workspace_id: Optional[int] = None) -> wallaroo.connection.ConnectionList:
@staticmethod
def get_connection( client: wallaroo.client.Client, name: str) -> wallaroo.connection.Connection:
@staticmethod
def create_connection( client: wallaroo.client.Client, name: str, connection_type: str, details: Dict[str, Any]) -> wallaroo.connection.Connection:
def delete_connection(self):
def add_connection_to_workspace(self, workspace_id: int):
def remove_connection_from_workspace(self, workspace_id: int):
def id(self):
def name(*args, **kwargs):
def connection_type(*args, **kwargs):
def details(*args, **kwargs):
def created_at(*args, **kwargs):
def workspace_names(*args, **kwargs):
class ConnectionList(typing.List[wallaroo.connection.Connection]):

Wraps a list of connections for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort